@@ -1,4 +1,4 @@
-/* C code produced by gperf version 3.0.4 */
+/* ANSI-C code produced by gperf version 3.1 */
 /* Command-line: gperf -a -c -C -o -t -p -T -k '1,2,$' -N lookup_element dtd.hash  */
 
 #if !((' ' == 32) && ('!' == 33) && ('"' == 34) && ('#' == 35) \
@@ -25,7 +25,7 @@
       && ('w' == 119) && ('x' == 120) && ('y' == 121) && ('z' == 122) \
       && ('{' == 123) && ('|' == 124) && ('}' == 125) && ('~' == 126))
 /* The character set is not based on ISO-646.  */
-error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gnu-gperf@gnu.org>."
+#error "gperf generated tables don't work with this execution character set. Please report a bug to <bug-gperf@gnu.org>."
 #endif
 
 #line 1 "dtd.hash"
@@ -79,7 +79,7 @@ EXPORT const ElementType * lookup_element(/* register const char *str,
 
 /* Different kinds of parent elements: */
 #define PHRASE "abbr", "acronym", "b", "bdi", "bdo", "big", "cite", "code", "dfn", "em", "i", "kbd", "q", "s", "samp", "small", "span", "strong", "sub", "sup", "time", "tt", "u", "var"
-#define BRIDGE "p", "address", "caption", "dt", "h1", "h2", "h3", "h4", "h5", "h6", "legend", "pre"
+#define BRIDGE "body", "p", "address", "caption", "dt", "h1", "h2", "h3", "h4", "h5", "h6", "legend", "pre"
 #define FLOW "article", "aside", "dd", "del", "details", "div", "fieldset", "figcaption", "figure", "footer", "header", "ins", "li", "nav", "section", "main", "object", "td", "th"
 #define INLINE_PARENT BRIDGE, PHRASE, FLOW
 #define BLOCK_PARENT "body", "blockquote", "map", "main"
@@ -99,9 +99,7 @@ inline
 #endif
 #endif
 static unsigned int
-hash (str, len)
-     register const char *str;
-     register unsigned int len;
+hash (register const char *str, register size_t len)
 {
   static const unsigned char asso_values[] =
     {
@@ -132,7 +130,7 @@ hash (str, len)
       228, 228, 228, 228, 228, 228, 228, 228, 228, 228,
       228, 228, 228, 228, 228, 228
     };
-  register int hval = len;
+  register unsigned int hval = len;
 
   switch (hval)
     {
@@ -146,16 +144,8 @@ hash (str, len)
   return hval + asso_values[(unsigned char)str[len - 1]];
 }
 
-#ifdef __GNUC__
-__inline
-#if defined __GNUC_STDC_INLINE__ || defined __GNUC_GNU_INLINE__
-__attribute__ ((__gnu_inline__))
-#endif
-#endif
 const ElementType *
-lookup_element (str, len)
-     register const char *str;
-     register unsigned int len;
+lookup_element (register const char *str, register size_t len)
 {
   static const ElementType wordlist[] =
     {
@@ -178,14 +168,14 @@ lookup_element (str, len)
       {"textarea",	1, 0, 0, 1, 1, 1, 0, 0, {INLINE_PARENT, "a", "label", NULL}},
       {""},
 #line 61 "dtd.hash"
-      {"%data",	1, 0, 0, 1, 0, 0, 0, 0, {"p", NULL}},
+      {"%data",	1, 0, 0, 1, 0, 0, 0, 0, {INLINE_PARENT, NULL}},
       {""},
 #line 84 "dtd.hash"
       {"dd",		1, 0, 0, 1, 0, 0, 1, 1, {"dl", NULL}},
 #line 85 "dtd.hash"
       {"del",		1, 0, 0, 1, 1, 0, 0, 0, {INLINE_PARENT, BLOCK_PARENT, "a", "button", "noscript", "form", "label", "option", "textarea", NULL}},
 #line 120 "dtd.hash"
-      {"meta",		0, 1, 0, 1, 0, 0, 1, 0, {INLINE_PARENT, "head", "a", "button", "noscript", "label", NULL}},
+      {"meta",		0, 1, 0, 1, 0, 0, 1, 0, {"head", INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 92 "dtd.hash"
       {"embed",		0, 1, 0, 1, 0, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
 #line 115 "dtd.hash"
@@ -323,7 +313,7 @@ lookup_element (str, len)
       {"fieldset",	1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "form", NULL}},
       {""}, {""},
 #line 132 "dtd.hash"
-      {"script",		1, 0, 1, 1, 1, 1, 1, 0, {"body", INLINE_PARENT, "blockquote", "head", "map", "a", "button", "noscript", "form", "label", NULL}},
+      {"script",		1, 0, 1, 1, 1, 1, 1, 0, {"head", "body", INLINE_PARENT, "blockquote", "map", "a", "button", "noscript", "form", "label", NULL}},
 #line 79 "dtd.hash"
       {"caption",	1, 0, 0, 1, 1, 0, 1, 1, {"table", NULL}},
 #line 87 "dtd.hash"
@@ -355,14 +345,14 @@ lookup_element (str, len)
 #line 121 "dtd.hash"
       {"nav",		1, 0, 0, 1, 1, 0, 1, 1, {BLOCK_PARENT, FLOW, "button", "noscript", "form", NULL}},
 #line 76 "dtd.hash"
-      {"body",		0, 0, 0, 0, 0, 0, 1, 1, {"html", NULL}},
+      {"body",		1, 0, 0, 0, 0, 0, 1, 1, {"html", NULL}},
 #line 94 "dtd.hash"
       {"figcaption",	1, 0, 0, 1, 1, 0, 1, 1, {"figure", NULL}},
       {""},
 #line 141 "dtd.hash"
-      {"summary",	1, 0, 0, 1, 1, 0, 0, 0, {"details", NULL}},
+      {"summary",	1, 0, 0, 1, 1, 0, 1, 1, {"details", NULL}},
 #line 157 "dtd.hash"
-      {"wbr",		0, 1, 0, 1, 0, 0, 0, 1, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
+      {"wbr",		0, 1, 0, 1, 0, 0, 0, 0, {INLINE_PARENT, "a", "button", "noscript", "label", NULL}},
       {""}, {""}, {""}, {""},
 #line 83 "dtd.hash"
       {"colgroup",	0, 0, 0, 1, 1, 0, 1, 1, {"table", NULL}},
@@ -403,9 +393,9 @@ lookup_element (str, len)
 
   if (len <= MAX_WORD_LENGTH && len >= MIN_WORD_LENGTH)
     {
-      register int key = hash (str, len);
+      register unsigned int key = hash (str, len);
 
-      if (key <= MAX_HASH_VALUE && key >= 0)
+      if (key <= MAX_HASH_VALUE)
         {
           register const char *s = wordlist[key].name;
 
