@@ -10,7 +10,7 @@
  * Author: Bert Bos <bert@w3.org>
  * Created: before 1995
  **/
-#include <config.h>
+#include "config.h"
 #include <stdlib.h>
 #include <stdio.h>
 #if STDC_HEADERS
@@ -24,8 +24,6 @@
 #include "export.h"
 
 #ifdef __export
-//#define FILE / ## *"*/__FI ## LE__/*"* ## /
-//#define LINE / ## *"*/__LI ## NE__/*"* ## /
 #undef __FILE__			/* Don't expand while making the .e file */
 #undef __LINE__			/* Don't expand while making the .e file */
 #endif
