@@ -1,8 +1,9 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.3.2.  */
 
 /* Bison implementation for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015, 2018-2019 Free Software Foundation,
+   Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -40,11 +41,14 @@
    define necessary library symbols; they are noted "INFRINGES ON
    USER NAME SPACE" below.  */
 
+/* Undocumented macros, especially those whose name start with YY_,
+   are private implementation details.  Do not rely on them.  */
+
 /* Identify Bison output.  */
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "3.0.2"
+#define YYBISON_VERSION "3.3.2"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -61,8 +65,8 @@
 
 
 
-/* Copy the first part of user declarations.  */
-#line 1 "html.y" /* yacc.c:339  */
+/* First part of user prologue.  */
+#line 1 "html.y" /* yacc.c:337  */
 
 /*
  * Simple XML grammar, with call-back functions.
@@ -164,13 +168,16 @@ static void yyerror(const string s)
 /* call -- if the function exists, call it with the given aguments */
 #define call(fn, args) do {if (fn) (fn)args;} while (0)
 
-#line 168 "html.c" /* yacc.c:339  */
-
+#line 172 "html.c" /* yacc.c:337  */
 # ifndef YY_NULLPTR
-#  if defined __cplusplus && 201103L <= __cplusplus
-#   define YY_NULLPTR nullptr
+#  if defined __cplusplus
+#   if 201103L <= __cplusplus
+#    define YY_NULLPTR nullptr
+#   else
+#    define YY_NULLPTR 0
+#   endif
 #  else
-#   define YY_NULLPTR 0
+#   define YY_NULLPTR ((void*)0)
 #  endif
 # endif
 
@@ -225,16 +232,18 @@ extern int yydebug;
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE YYSTYPE;
+
 union YYSTYPE
 {
-#line 103 "html.y" /* yacc.c:355  */
+#line 103 "html.y" /* yacc.c:352  */
 
     string s;
     pairlist p;
 
-#line 237 "html.c" /* yacc.c:355  */
+#line 244 "html.c" /* yacc.c:352  */
 };
+
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
 #endif
@@ -246,9 +255,7 @@ int yyparse (void);
 
 #endif /* !YY_YY_HTML_H_INCLUDED  */
 
-/* Copy the second part of user declarations.  */
 
-#line 252 "html.c" /* yacc.c:358  */
 
 #ifdef short
 # undef short
@@ -269,13 +276,13 @@ typedef signed char yytype_int8;
 #ifdef YYTYPE_UINT16
 typedef YYTYPE_UINT16 yytype_uint16;
 #else
-typedef unsigned short int yytype_uint16;
+typedef unsigned short yytype_uint16;
 #endif
 
 #ifdef YYTYPE_INT16
 typedef YYTYPE_INT16 yytype_int16;
 #else
-typedef short int yytype_int16;
+typedef short yytype_int16;
 #endif
 
 #ifndef YYSIZE_T
@@ -287,7 +294,7 @@ typedef short int yytype_int16;
 #  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
 #  define YYSIZE_T size_t
 # else
-#  define YYSIZE_T unsigned int
+#  define YYSIZE_T unsigned
 # endif
 #endif
 
@@ -323,15 +330,6 @@ typedef short int yytype_int16;
 # define YY_ATTRIBUTE_UNUSED YY_ATTRIBUTE ((__unused__))
 #endif
 
-#if !defined _Noreturn \
-     && (!defined __STDC_VERSION__ || __STDC_VERSION__ < 201112)
-# if defined _MSC_VER && 1200 <= _MSC_VER
-#  define _Noreturn __declspec (noreturn)
-# else
-#  define _Noreturn YY_ATTRIBUTE ((__noreturn__))
-# endif
-#endif
-
 /* Suppress unused-variable warnings by "using" E.  */
 #if ! defined lint || defined __GNUC__
 # define YYUSE(E) ((void) (E))
@@ -339,7 +337,7 @@ typedef short int yytype_int16;
 # define YYUSE(E) /* empty */
 #endif
 
-#if defined __GNUC__ && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
+#if defined __GNUC__ && ! defined __ICC && 407 <= __GNUC__ * 100 + __GNUC_MINOR__
 /* Suppress an incorrect diagnostic about yylval being uninitialized.  */
 # define YY_IGNORE_MAYBE_UNINITIALIZED_BEGIN \
     _Pragma ("GCC diagnostic push") \
@@ -501,16 +499,16 @@ union yyalloc
 /* YYNSTATES -- Number of states.  */
 #define YYNSTATES  33
 
-/* YYTRANSLATE[YYX] -- Symbol number corresponding to YYX as returned
-   by yylex, with out-of-bounds checking.  */
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   267
 
+/* YYTRANSLATE(TOKEN-NUM) -- Symbol number corresponding to TOKEN-NUM
+   as returned by yylex, with out-of-bounds checking.  */
 #define YYTRANSLATE(YYX)                                                \
-  ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
+  ((unsigned) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[TOKEN-NUM] -- Symbol number corresponding to TOKEN-NUM
-   as returned by yylex, without out-of-bounds checking.  */
+   as returned by yylex.  */
 static const yytype_uint8 yytranslate[] =
 {
        0,     2,     2,     2,     2,     2,     2,     2,     2,     2,
@@ -673,22 +671,22 @@ static const yytype_uint8 yyr2[] =
 
 #define YYRECOVERING()  (!!yyerrstatus)
 
-#define YYBACKUP(Token, Value)                                  \
-do                                                              \
-  if (yychar == YYEMPTY)                                        \
-    {                                                           \
-      yychar = (Token);                                         \
-      yylval = (Value);                                         \
-      YYPOPSTACK (yylen);                                       \
-      yystate = *yyssp;                                         \
-      goto yybackup;                                            \
-    }                                                           \
-  else                                                          \
-    {                                                           \
-      yyerror (YY_("syntax error: cannot back up")); \
-      YYERROR;                                                  \
-    }                                                           \
-while (0)
+#define YYBACKUP(Token, Value)                                    \
+  do                                                              \
+    if (yychar == YYEMPTY)                                        \
+      {                                                           \
+        yychar = (Token);                                         \
+        yylval = (Value);                                         \
+        YYPOPSTACK (yylen);                                       \
+        yystate = *yyssp;                                         \
+        goto yybackup;                                            \
+      }                                                           \
+    else                                                          \
+      {                                                           \
+        yyerror (YY_("syntax error: cannot back up")); \
+        YYERROR;                                                  \
+      }                                                           \
+  while (0)
 
 /* Error token number */
 #define YYTERROR        1
@@ -728,37 +726,37 @@ do {                                                                      \
 } while (0)
 
 
-/*----------------------------------------.
-| Print this symbol's value on YYOUTPUT.  |
-`----------------------------------------*/
+/*-----------------------------------.
+| Print this symbol's value on YYO.  |
+`-----------------------------------*/
 
 static void
-yy_symbol_value_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_value_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep)
 {
-  FILE *yyo = yyoutput;
-  YYUSE (yyo);
+  FILE *yyoutput = yyo;
+  YYUSE (yyoutput);
   if (!yyvaluep)
     return;
 # ifdef YYPRINT
   if (yytype < YYNTOKENS)
-    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+    YYPRINT (yyo, yytoknum[yytype], *yyvaluep);
 # endif
   YYUSE (yytype);
 }
 
 
-/*--------------------------------.
-| Print this symbol on YYOUTPUT.  |
-`--------------------------------*/
+/*---------------------------.
+| Print this symbol on YYO.  |
+`---------------------------*/
 
 static void
-yy_symbol_print (FILE *yyoutput, int yytype, YYSTYPE const * const yyvaluep)
+yy_symbol_print (FILE *yyo, int yytype, YYSTYPE const * const yyvaluep)
 {
-  YYFPRINTF (yyoutput, "%s %s (",
+  YYFPRINTF (yyo, "%s %s (",
              yytype < YYNTOKENS ? "token" : "nterm", yytname[yytype]);
 
-  yy_symbol_value_print (yyoutput, yytype, yyvaluep);
-  YYFPRINTF (yyoutput, ")");
+  yy_symbol_value_print (yyo, yytype, yyvaluep);
+  YYFPRINTF (yyo, ")");
 }
 
 /*------------------------------------------------------------------.
@@ -792,7 +790,7 @@ do {                                                            \
 static void
 yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
 {
-  unsigned long int yylno = yyrline[yyrule];
+  unsigned long yylno = yyrline[yyrule];
   int yynrhs = yyr2[yyrule];
   int yyi;
   YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu):\n",
@@ -803,7 +801,7 @@ yy_reduce_print (yytype_int16 *yyssp, YYSTYPE *yyvsp, int yyrule)
       YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr,
                        yystos[yyssp[yyi + 1 - yynrhs]],
-                       &(yyvsp[(yyi + 1) - (yynrhs)])
+                       &yyvsp[(yyi + 1) - (yynrhs)]
                                               );
       YYFPRINTF (stderr, "\n");
     }
@@ -907,7 +905,10 @@ yytnamerr (char *yyres, const char *yystr)
           case '\\':
             if (*++yyp != '\\')
               goto do_not_strip_quotes;
-            /* Fall through.  */
+            else
+              goto append;
+
+          append:
           default:
             if (yyres)
               yyres[yyn] = *yyp;
@@ -925,7 +926,7 @@ yytnamerr (char *yyres, const char *yystr)
   if (! yyres)
     return yystrlen (yystr);
 
-  return yystpcpy (yyres, yystr) - yyres;
+  return (YYSIZE_T) (yystpcpy (yyres, yystr) - yyres);
 }
 # endif
 
@@ -1003,10 +1004,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
                 yyarg[yycount++] = yytname[yyx];
                 {
                   YYSIZE_T yysize1 = yysize + yytnamerr (YY_NULLPTR, yytname[yyx]);
-                  if (! (yysize <= yysize1
-                         && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+                  if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+                    yysize = yysize1;
+                  else
                     return 2;
-                  yysize = yysize1;
                 }
               }
         }
@@ -1018,6 +1019,7 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
       case N:                               \
         yyformat = S;                       \
       break
+    default: /* Avoid compiler warnings. */
       YYCASE_(0, YY_("syntax error"));
       YYCASE_(1, YY_("syntax error, unexpected %s"));
       YYCASE_(2, YY_("syntax error, unexpected %s, expecting %s"));
@@ -1029,9 +1031,10 @@ yysyntax_error (YYSIZE_T *yymsg_alloc, char **yymsg,
 
   {
     YYSIZE_T yysize1 = yysize + yystrlen (yyformat);
-    if (! (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM))
+    if (yysize <= yysize1 && yysize1 <= YYSTACK_ALLOC_MAXIMUM)
+      yysize = yysize1;
+    else
       return 2;
-    yysize = yysize1;
   }
 
   if (*yymsg_alloc < yysize)
@@ -1157,23 +1160,31 @@ yyparse (void)
   yychar = YYEMPTY; /* Cause a token to be read.  */
   goto yysetstate;
 
+
 /*------------------------------------------------------------.
-| yynewstate -- Push a new state, which is found in yystate.  |
+| yynewstate -- push a new state, which is found in yystate.  |
 `------------------------------------------------------------*/
- yynewstate:
+yynewstate:
   /* In all cases, when you get here, the value and location stacks
      have just been pushed.  So pushing a state here evens the stacks.  */
   yyssp++;
 
- yysetstate:
-  *yyssp = yystate;
+
+/*--------------------------------------------------------------------.
+| yynewstate -- set current state (the top of the stack) to yystate.  |
+`--------------------------------------------------------------------*/
+yysetstate:
+  *yyssp = (yytype_int16) yystate;
 
   if (yyss + yystacksize - 1 <= yyssp)
+#if !defined yyoverflow && !defined YYSTACK_RELOCATE
+    goto yyexhaustedlab;
+#else
     {
       /* Get the current used size of the three stacks, in elements.  */
-      YYSIZE_T yysize = yyssp - yyss + 1;
+      YYSIZE_T yysize = (YYSIZE_T) (yyssp - yyss + 1);
 
-#ifdef yyoverflow
+# if defined yyoverflow
       {
         /* Give user a chance to reallocate the stack.  Use copies of
            these so that the &'s don't force the real ones into
@@ -1189,14 +1200,10 @@ yyparse (void)
                     &yyss1, yysize * sizeof (*yyssp),
                     &yyvs1, yysize * sizeof (*yyvsp),
                     &yystacksize);
-
         yyss = yyss1;
         yyvs = yyvs1;
       }
-#else /* no yyoverflow */
-# ifndef YYSTACK_RELOCATE
-      goto yyexhaustedlab;
-# else
+# else /* defined YYSTACK_RELOCATE */
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
         goto yyexhaustedlab;
@@ -1212,22 +1219,22 @@ yyparse (void)
           goto yyexhaustedlab;
         YYSTACK_RELOCATE (yyss_alloc, yyss);
         YYSTACK_RELOCATE (yyvs_alloc, yyvs);
-#  undef YYSTACK_RELOCATE
+# undef YYSTACK_RELOCATE
         if (yyss1 != yyssa)
           YYSTACK_FREE (yyss1);
       }
 # endif
-#endif /* no yyoverflow */
 
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
-                  (unsigned long int) yystacksize));
+                  (unsigned long) yystacksize));
 
       if (yyss + yystacksize - 1 <= yyssp)
         YYABORT;
     }
+#endif /* !defined yyoverflow && !defined YYSTACK_RELOCATE */
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
@@ -1236,11 +1243,11 @@ yyparse (void)
 
   goto yybackup;
 
+
 /*-----------.
 | yybackup.  |
 `-----------*/
 yybackup:
-
   /* Do appropriate processing given the current state.  Read a
      lookahead token if we need one and don't already have one.  */
 
@@ -1313,7 +1320,7 @@ yydefault:
 
 
 /*-----------------------------.
-| yyreduce -- Do a reduction.  |
+| yyreduce -- do a reduction.  |
 `-----------------------------*/
 yyreduce:
   /* yyn is the number of a rule to reduce with.  */
@@ -1334,118 +1341,118 @@ yyreduce:
   switch (yyn)
     {
         case 2:
-#line 116 "html.y" /* yacc.c:1646  */
+#line 116 "html.y" /* yacc.c:1652  */
     {data = h.start ? h.start() : NULL;}
-#line 1340 "html.c" /* yacc.c:1646  */
+#line 1347 "html.c" /* yacc.c:1652  */
     break;
 
   case 3:
-#line 117 "html.y" /* yacc.c:1646  */
+#line 117 "html.y" /* yacc.c:1652  */
     {call(h.end, (data));}
-#line 1346 "html.c" /* yacc.c:1646  */
+#line 1353 "html.c" /* yacc.c:1652  */
     break;
 
   case 4:
-#line 120 "html.y" /* yacc.c:1646  */
+#line 120 "html.y" /* yacc.c:1652  */
     {call(h.comment, (data, (yyvsp[0].s)));}
-#line 1352 "html.c" /* yacc.c:1646  */
+#line 1359 "html.c" /* yacc.c:1652  */
     break;
 
   case 5:
-#line 121 "html.y" /* yacc.c:1646  */
+#line 121 "html.y" /* yacc.c:1652  */
     {call(h.text, (data, (yyvsp[0].s)));}
-#line 1358 "html.c" /* yacc.c:1646  */
+#line 1365 "html.c" /* yacc.c:1652  */
     break;
 
   case 9:
-#line 125 "html.y" /* yacc.c:1646  */
+#line 125 "html.y" /* yacc.c:1652  */
     {call(h.pi, (data, (yyvsp[0].s)));}
-#line 1364 "html.c" /* yacc.c:1646  */
+#line 1371 "html.c" /* yacc.c:1652  */
     break;
 
   case 10:
-#line 126 "html.y" /* yacc.c:1646  */
+#line 126 "html.y" /* yacc.c:1652  */
     {call(h.endincl, (data));}
-#line 1370 "html.c" /* yacc.c:1646  */
+#line 1377 "html.c" /* yacc.c:1652  */
     break;
 
   case 13:
-#line 131 "html.y" /* yacc.c:1646  */
+#line 131 "html.y" /* yacc.c:1652  */
     {call(h.starttag, (data, (yyvsp[-2].s), (yyvsp[-1].p)));}
-#line 1376 "html.c" /* yacc.c:1646  */
+#line 1383 "html.c" /* yacc.c:1652  */
     break;
 
   case 14:
-#line 132 "html.y" /* yacc.c:1646  */
+#line 132 "html.y" /* yacc.c:1652  */
     {call(h.emptytag, (data, (yyvsp[-2].s), (yyvsp[-1].p)));}
-#line 1382 "html.c" /* yacc.c:1646  */
+#line 1389 "html.c" /* yacc.c:1652  */
     break;
 
   case 15:
-#line 135 "html.y" /* yacc.c:1646  */
+#line 135 "html.y" /* yacc.c:1652  */
     {(yyval.p) = (yyvsp[-1].p); (yyval.p)->next = (yyvsp[0].p);}
-#line 1388 "html.c" /* yacc.c:1646  */
+#line 1395 "html.c" /* yacc.c:1652  */
     break;
 
   case 16:
-#line 136 "html.y" /* yacc.c:1646  */
+#line 136 "html.y" /* yacc.c:1652  */
     {(yyval.p) = NULL;}
-#line 1394 "html.c" /* yacc.c:1646  */
+#line 1401 "html.c" /* yacc.c:1652  */
     break;
 
   case 17:
-#line 139 "html.y" /* yacc.c:1646  */
+#line 139 "html.y" /* yacc.c:1652  */
     {pairlist h = malloc(sizeof(*h));
 					 assert(h != NULL); h->name = (yyvsp[0].s);
 					 h->value=NULL; (yyval.p) = h;}
-#line 1402 "html.c" /* yacc.c:1646  */
+#line 1409 "html.c" /* yacc.c:1652  */
     break;
 
   case 18:
-#line 142 "html.y" /* yacc.c:1646  */
+#line 142 "html.y" /* yacc.c:1652  */
     {pairlist h = malloc(sizeof(*h));
 					 assert(h != NULL); h->name = (yyvsp[-2].s);
 					 h->value = (yyvsp[0].s); (yyval.p) = h;}
-#line 1410 "html.c" /* yacc.c:1646  */
+#line 1417 "html.c" /* yacc.c:1652  */
     break;
 
   case 19:
-#line 145 "html.y" /* yacc.c:1646  */
+#line 145 "html.y" /* yacc.c:1652  */
     {pairlist h = malloc(sizeof(*h));
 					 assert(h != NULL); h->name = (yyvsp[-2].s);
 					 h->value = (yyvsp[0].s); (yyval.p) = h;}
-#line 1418 "html.c" /* yacc.c:1646  */
+#line 1425 "html.c" /* yacc.c:1652  */
     break;
 
   case 20:
-#line 150 "html.y" /* yacc.c:1646  */
+#line 150 "html.y" /* yacc.c:1652  */
     {call(h.endtag, (data, (yyvsp[-1].s)));}
-#line 1424 "html.c" /* yacc.c:1646  */
+#line 1431 "html.c" /* yacc.c:1652  */
     break;
 
   case 21:
-#line 153 "html.y" /* yacc.c:1646  */
+#line 153 "html.y" /* yacc.c:1652  */
     {call(h.decl, (data, (yyvsp[-4].s), (yyvsp[-2].s), (yyvsp[-1].s)));}
-#line 1430 "html.c" /* yacc.c:1646  */
+#line 1437 "html.c" /* yacc.c:1652  */
     break;
 
   case 22:
-#line 154 "html.y" /* yacc.c:1646  */
+#line 154 "html.y" /* yacc.c:1652  */
     {if (strcasecmp((yyvsp[-2].s), "public") == 0)
 				     	   call(h.decl, (data, (yyvsp[-3].s), (yyvsp[-1].s), NULL));
 					 else /* "system" */
 					   call(h.decl, (data, (yyvsp[-3].s), NULL, (yyvsp[-1].s)));}
-#line 1439 "html.c" /* yacc.c:1646  */
+#line 1446 "html.c" /* yacc.c:1652  */
     break;
 
   case 23:
-#line 158 "html.y" /* yacc.c:1646  */
+#line 158 "html.y" /* yacc.c:1652  */
     {call(h.decl, (data, (yyvsp[-1].s), NULL, NULL));}
-#line 1445 "html.c" /* yacc.c:1646  */
+#line 1452 "html.c" /* yacc.c:1652  */
     break;
 
 
-#line 1449 "html.c" /* yacc.c:1646  */
+#line 1456 "html.c" /* yacc.c:1652  */
       default: break;
     }
   /* User semantic actions sometimes alter yychar, and that requires
@@ -1470,14 +1477,13 @@ yyreduce:
   /* Now 'shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
-
-  yyn = yyr1[yyn];
-
-  yystate = yypgoto[yyn - YYNTOKENS] + *yyssp;
-  if (0 <= yystate && yystate <= YYLAST && yycheck[yystate] == *yyssp)
-    yystate = yytable[yystate];
-  else
-    yystate = yydefgoto[yyn - YYNTOKENS];
+  {
+    const int yylhs = yyr1[yyn] - YYNTOKENS;
+    const int yyi = yypgoto[yylhs] + *yyssp;
+    yystate = (0 <= yyi && yyi <= YYLAST && yycheck[yyi] == *yyssp
+               ? yytable[yyi]
+               : yydefgoto[yylhs]);
+  }
 
   goto yynewstate;
 
@@ -1560,12 +1566,10 @@ yyerrlab:
 | yyerrorlab -- error raised explicitly by YYERROR.  |
 `---------------------------------------------------*/
 yyerrorlab:
-
-  /* Pacify compilers like GCC when the user code never invokes
-     YYERROR and the label yyerrorlab therefore never appears in user
-     code.  */
-  if (/*CONSTCOND*/ 0)
-     goto yyerrorlab;
+  /* Pacify compilers when the user code never invokes YYERROR and the
+     label yyerrorlab therefore never appears in user code.  */
+  if (0)
+    YYERROR;
 
   /* Do not reclaim the symbols of the rule whose action triggered
      this YYERROR.  */
@@ -1627,6 +1631,7 @@ yyacceptlab:
   yyresult = 0;
   goto yyreturn;
 
+
 /*-----------------------------------.
 | yyabortlab -- YYABORT comes here.  |
 `-----------------------------------*/
@@ -1634,6 +1639,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
+
 #if !defined yyoverflow || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
@@ -1644,6 +1650,10 @@ yyexhaustedlab:
   /* Fall through.  */
 #endif
 
+
+/*-----------------------------------------------------.
+| yyreturn -- parsing is finished, return the result.  |
+`-----------------------------------------------------*/
 yyreturn:
   if (yychar != YYEMPTY)
     {
