@@ -6,7 +6,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 20 Aug 2000
- * Version: $Id: hxaddid.c,v 1.8 2017/11/24 09:50:25 bbos Exp $
+ * Version: $Id: hxaddid.c,v 1.9 2023/01/23 21:19:41 bbos Exp $
  *
  **/
 #include "config.h"
@@ -15,6 +15,8 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
+#include <err.h>
+#include <sysexits.h>
 #include <stdbool.h>
 #if STDC_HEADERS
 # include <string.h>
@@ -39,7 +41,6 @@
 #include "scan.e"
 #include "dict.e"
 #include "openurl.e"
-#include "errexit.e"
 #include "genid.e"
 #include "class.e"
 
@@ -169,8 +170,9 @@ static void expand(Tree t)
 /* usage -- print usage message and exit */
 static void usage(string name)
 {
-  errexit("Usage: %s [-x] [-v] [--] elem|.class|elem.class [html-file]\n",
-	  name);
+  fprintf(stderr,
+    "Usage: %s [-x] [-v] [--] elem|.class|elem.class [html-file]\n", name);
+  exit(EX_USAGE);
 }
 
 
@@ -217,8 +219,8 @@ int main(int argc, char *argv[])
   else if (i == argc - 1) yyin = fopenurl(argv[i], "r", &status);
   else usage(argv[0]);
 
-  if (yyin == NULL) {perror(argv[i]); exit(1);}
-  if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
+  if (yyin == NULL) err(EX_IOERR, "%s", argv[i]);
+  if (status != 200) errx(EX_IOERR, "%s: %s", argv[i], http_strerror(status));
 
   if (yyparse() != 0) exit(3);
 
