@@ -19,7 +19,7 @@
  *
  * Author: Bert Bos
  * Created: 2 Dec 1998
- * Version: $Id: hxincl.c,v 1.14 2017/11/24 09:50:25 bbos Exp $
+ * Version: $Id: hxincl.c,v 1.15 2023/01/23 21:19:41 bbos Exp $
  *
  **/
 #include "config.h"
@@ -42,10 +42,10 @@
 #include <stdlib.h>
 #include <assert.h>
 #include <err.h>
+#include <sysexits.h>
 #include <stdbool.h>
 #include "export.h"
 #include "types.e"
-#include "errexit.e"
 #include "html.e"
 #include "scan.e"
 #include "dict.e"
@@ -118,10 +118,11 @@ static void add_substitution(const string assignment)
 
   /* To do: handle file names containing '='. Add escapes? */
   if (!substitutions) substitutions = dict_create(10);
-  if (!substitutions) errexit("Out of memory.\n");
-  if (!(s = strchr(assignment, '='))) errexit("No '=' found in option -s\n");
+  if (!substitutions) err(EX_OSERR, NULL);
+  if (!(s = strchr(assignment, '=')))
+    errx(EX_USAGE, "No '=' found in option -s");
   *s = '\0';
-  if (!dict_add(substitutions, assignment, s + 1)) errexit("Out of memory?\n");
+  if (!dict_add(substitutions, assignment, s + 1)) err(EX_OSERR, NULL);
   *s = '=';
 }
 
@@ -242,10 +243,10 @@ void handle_comment(void *clientdata, string commenttext)
     s = URL_s_absolutize(get_yyin_name(), url);
     if (target) printf(" \\\n %s", s); /* To do: escape spaces in s */
     if (!(f = fopenurl(s, "r", &status))) {
-      if (!target || warn_missing) perror(url);
+      if (!target || warn_missing) warn("%s", url);
     } else if (status != 200) {
       if (!target || warn_missing)
-	fprintf(stderr, "%s : %s\n", url, http_strerror(status));
+	warn("%s : %s\n", url, http_strerror(status));
     } else {
       if (!final && !target) printf("<!--%s %s-->", BEGIN, commenttext + i);
       push(&skipping, false);
@@ -387,8 +388,8 @@ int main(int argc, char *argv[])
     usage(argv[0]);
   }
 
-  if (yyin == NULL) {perror(argv[optind]); exit(1);}
-  if (status != 200) errexit("%s : %s\n", argv[optind], http_strerror(status));
+  if (yyin == NULL) err(EX_IOERR, "%s", argv[optind]);
+  if (status != 200) errx(EX_IOERR,"%s: %s",argv[optind],http_strerror(status));
 
   if (target) printf("%s:", target);
   if (yyparse() != 0) exit(3);
