@@ -30,6 +30,8 @@
 #endif
 #include <stdlib.h>
 #include <assert.h>
+#include <err.h>
+#include <sysexits.h>
 #include <stdbool.h>
 #include "export.h"
 #include "types.e"
@@ -37,7 +39,6 @@
 #include "scan.e"
 #include "dict.e"
 #include "openurl.e"
-#include "errexit.e"
 
 #define XML "{http://www.w3.org/XML/1998/namespace}"
 
@@ -207,8 +208,8 @@ int main(int argc, char *argv[])
   else if (argc == 2) yyin = fopenurl(argv[1], "r", &status);
   else yyin = stdin;
 
-  if (!yyin) {perror(argv[1]); exit(1);}
-  if (status != 200) errexit("%s : %s\n", argv[1], http_strerror(status));
+  if (!yyin) err(EX_IOERR, "%s", argv[1]);
+  if (status != 200) errx(EX_IOERR, "%s: %s\n", argv[1], http_strerror(status));
 
   if (yyparse() != 0) exit(3);
 
