@@ -6,7 +6,7 @@
  *
  * Bert Bos <bert@w3.org>
  * Created Feb 2000
- * $Id: hxprune.c,v 1.8 2017/11/24 09:50:25 bbos Exp $
+ * $Id: hxprune.c,v 1.10 2023/01/23 21:25:05 bbos Exp $
  *
  **/
 /* #include <mcheck.h> */
@@ -16,6 +16,8 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
+#include <err.h>
+#include <sysexits.h>
 #include <stdbool.h>
 #if STDC_HEADERS
 # include <string.h>
@@ -36,7 +38,6 @@
 #include "dict.e"
 #include "openurl.e"
 #include "class.e"
-#include "errexit.e"
 
 #define EXCLUDE_CLASS "exclude"			/* Default value for class */
 
@@ -192,8 +193,8 @@ int main(int argc, char *argv[])
       xml = true;
     } else {
       yyin = fopenurl(argv[i], "r", &status);
-      if (yyin == NULL) {perror(argv[1]); exit(2);}
-      if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
+      if (yyin == NULL) err(EX_IOERR, "%s", argv[1]);
+      if (status != 200) errx(EX_IOERR,"%s: %s",argv[i],http_strerror(status));
     }
   }
 
