@@ -42,7 +42,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created: 5 Jul 2001
- * Version: $Id: hxselect.c,v 1.10 2017/11/24 09:50:25 bbos Exp $
+ * Version: $Id: hxselect.c,v 1.13 2023/02/09 17:19:41 bbos Exp $
  *
  **/
 #include "config.h"
@@ -51,6 +51,8 @@
 #include <stdlib.h>
 #include <unistd.h>
 #include <ctype.h>
+#include <err.h>
+#include <sysexits.h>
 #include <stdbool.h>
 #if STDC_HEADERS
 # include <string.h>
@@ -67,7 +69,6 @@
 #include "tree.e"
 #include "selector.e"
 #include "heap.e"
-#include "errexit.e"
 #include "html.e"
 #include "scan.e"
 #include "selmatch.e"
@@ -102,9 +103,9 @@ static void printsep(const string separator)
       c = *s - '0';
       if ('0' <= *(++s) && *s <= '7') {
 	c = 8 * c + *s - '0';
-	if ('0' <= *(++s) && *s <= '7') c = 8 * c + *s - '0';
+	if ('0' <= *(++s) && *s <= '7') c = 8 * c + *(s++) - '0';
       }
-      putchar(c); s++;
+      putchar(c);
     } else
       switch (*s) {
       case '\0': putchar('\\'); break;
@@ -156,19 +157,22 @@ static void print_tree(Tree t)
 static void match_pseudoelts(Tree t)
 {
   pairlist p;
+  Selector s;
 
-  assert(selector->pseudoelts);
+  for (s = selector; s; s = s->next) {
+    if (!s->pseudoelts) continue;
 
-  /* ::attr() is the only pseudo-element we can handle so far */
-  if (selector->pseudoelts->type == AttrNode) {
-    assert(selector->combinator == Child && selector->context);
-    p = t->attribs;
-    while (p && !same(p->name, selector->pseudoelts->s)) p = p->next;
-    if (p && matches_sel(t, selector->context)) {
-      if (!content_only) printf("%s=\"", p->name);
-      printf("%s", p->value);
-      if (!content_only) printf("\"");
-      printsep(separator);
+    /* ::attr() is the only pseudo-element we can handle so far */
+    if (s->pseudoelts->type == AttrNode) {
+      assert(s->combinator == Child && s->context);
+      p = t->attribs;
+      while (p && !same(p->name, s->pseudoelts->s)) p = p->next;
+      if (p && matches_sel(t, s->context)) {
+	if (!content_only) printf("%s=\"", p->name);
+	printf("%s", p->value);
+	if (!content_only) printf("\"");
+	printsep(separator);
+      }
     }
   }
 }
@@ -181,8 +185,8 @@ static void walk_tree(Tree t)
 
   switch (t->tp) {
   case Element:
-    if (selector->pseudoelts) match_pseudoelts(t);
-    else if (matches_sel(t, selector)) print_tree(t);
+    if (matches_sel(t, selector)) print_tree(t);
+    match_pseudoelts(t);
     walk_tree(t->children);
     break;
   case Text: break;
@@ -290,8 +294,10 @@ static void handle_endtag(void *clientdata, const string name)
 /* usage -- print usage message and exit */
 static void usage(const conststring progname)
 {
-  errexit("Usage: %s [-v] [-i] [-c] [-l language] [-s separator] selector\n",
+  fprintf(stderr,
+    "Usage: %s [-v] [-i] [-c] [-l language] [-s separator] selector\n",
 	  progname);
+  exit(EX_USAGE);
 }
 
 
@@ -330,7 +336,7 @@ int main(int argc, char *argv[])
   for (s = newstring(argv[optind++]); optind < argc; optind++)
     strapp(&s, " ", argv[optind], NULL);
   selector = parse_selector(s, &s);
-  if (*s) errexit("Syntax error at \"%c\"\n", *s);
+  if (*s) errx(EX_DATAERR, "Syntax error at \"%c\"\n", *s);
 
   /* Walk the tree */
   yyin = stdin;
