@@ -23,7 +23,7 @@
  *
  * Author: Bert Bos <bert@w3.org>
  * Created Sep 1997
- * Version: $Id: hxtoc.c,v 1.13 2019/08/28 19:14:07 bbos Exp $
+ * Version: $Id: hxtoc.c,v 1.14 2023/01/23 21:19:41 bbos Exp $
  *
  **/
 #include "config.h"
@@ -32,6 +32,8 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <time.h>
+#include <err.h>
+#include <sysexits.h>
 #include <stdbool.h>
 #include <getopt.h>
 #include <limits.h>
@@ -64,7 +66,6 @@
 #include "scan.e"
 #include "dict.e"
 #include "openurl.e"
-#include "errexit.e"
 #include "genid.e"
 #include "class.e"
 
@@ -442,8 +443,9 @@ static void expand(Tree t, bool *write, bool exp, bool keep_anchors,
 /* usage -- print usage message and exit */
 static void usage(string name)
 {
-  errexit("Version %s\nUsage: %s [-l low] [-h high] [-x] [-t] [-d] [-c class] [html-file]\n",
+  fprintf(stderr, "Version %s\nUsage: %s [-l low] [-h high] [-x] [-t] [-d] [-c class] [html-file]\n",
 	  VERSION, name);
+  exit(EX_USAGE);
 }
 
 
@@ -471,9 +473,9 @@ int main(int argc, char *argv[])
   } else if (optind >= argc || eq(argv[optind], "-")) {
     yyin = stdin;
   } else if (!(yyin = fopenurl(argv[optind], "r", &status))) {
-    perror(argv[optind]); exit(2);
+    err(EX_IOERR, "%s", argv[optind]);
   } else if (status != 200) {
-    errexit("%s : %s\n", argv[optind], http_strerror(status));
+    errx(EX_IOERR, "%s: %s", argv[optind], http_strerror(status));
   }
 
   /* Bind the parser callback routines to our handlers */
