@@ -11,7 +11,7 @@
  *
  * Author: Bert Bos
  * Created: 8 November 2005
- * Version: $Id: hxunxmlns.c,v 1.7 2017/11/24 09:50:25 bbos Exp $
+ * Version: $Id: hxunxmlns.c,v 1.8 2023/01/23 21:19:41 bbos Exp $
  *
  **/
 #include "config.h"
@@ -30,6 +30,8 @@
 #endif
 #include <stdlib.h>
 #include <assert.h>
+#include <err.h>
+#include <sysexits.h>
 #include <stdbool.h>
 #include "export.h"
 #include "types.e"
@@ -37,7 +39,6 @@
 #include "scan.e"
 #include "dict.e"
 #include "openurl.e"
-#include "errexit.e"
 
 
 #define XMLNS "{http://www.w3.org/XML/1998/namespace}"
@@ -215,8 +216,8 @@ int main(int argc, char *argv[])
   else if (i == argc - 1) yyin = fopenurl(argv[i], "r", &status);
   else usage(argv[0]);
 
-  if (yyin == NULL) {perror(argv[i]); exit(1);}
-  if (status != 200) errexit("%s : %s\n", argv[i], http_strerror(status));
+  if (yyin == NULL) err(EX_IOERR, "%s", argv[i]);
+  if (status != 200) errx(EX_IOERR, "%s: %s", argv[i], http_strerror(status));
 
   if (yyparse() != 0) exit(3);
 
