@@ -69,6 +69,8 @@
 #include <stdlib.h>
 #include <stdarg.h>
 #include <assert.h>
+#include <err.h>
+#include <sysexits.h>
 #include "export.h"
 #if HAVE_LIBCURL && !HAVE_FOPENCOOKIE
 # include "fopencookie.h"	/* Use our own fopencookie() */
@@ -76,7 +78,6 @@
 #include "dict.e"
 #include "heap.e"
 #include "types.e"
-#include "errexit.e"
 
 #define MAXREDIRECTS 10		/* Maximum # of 30x redirects to follow */
 
@@ -238,7 +239,7 @@ static CURLcode wait_for_data(URL_FILE *file, size_t want)
     while (rc == CURLM_CALL_MULTI_PERFORM);
 
     if (rc == CURLM_OUT_OF_MEMORY) return CURLE_OUT_OF_MEMORY;
-    if (rc != CURLM_OK) errexit("Error waiting for data (%d)\n", rc);
+    if (rc != CURLM_OK) errx(EX_IOERR, "Error waiting for data (%d)", rc);
 
     /* Stop if the connection is closed, after checking why */
     if (!file->still_running) {
@@ -266,11 +267,11 @@ static CURLcode wait_for_data(URL_FILE *file, size_t want)
     maxfd = -1;
     rc = curl_multi_fdset(multi_handle, &fdread, &fdwrite, &fdexcep, &maxfd);
     if (rc == CURLM_OUT_OF_MEMORY) return CURLE_OUT_OF_MEMORY;
-    if (rc != CURLM_OK) errexit("Error waiting for data (%d)\n", rc);
+    if (rc != CURLM_OK) errx(EX_IOERR, "Error waiting for data (%d)", rc);
 
     /* Call select() to wait for either some data or a timeout */
     if (select(maxfd + 1, &fdread, &fdwrite, &fdexcep, &timeout) < 0)
-      errexit("select error: %s\n", strerror(errno));
+      err(EX_IOERR, "in select()");
   }
 
   return CURLE_OK;
