@@ -32,7 +32,8 @@ cat >$TMP6 <<EOF
 <li>term1, <a href="foo1#term1"><strong>#</strong></a>, <a href="foo2#term1"><strong>#</strong></a>
 <li>term2, <a href="foo1#term2"><strong>#</strong></a>
 <li>term3, <a href="foo2#term3"><strong>#</strong></a>
-</ul><!--end-index--></body></html>
+</ul><!--end-index-->
+</body></html>
 EOF
 
 # Check.
