@@ -23,10 +23,15 @@ EOF
 (./hxnum $TMP1 | LC_ALL=C ./hxindex -t -n -f; echo) >$TMP2
 
 cat >$TMP3 <<EOF
-<html><body><h1><span class="secno">1. </span>Heading 0</h1><h1 class="no-num">Heading 1</h1><p><dfn id="a-term">A-term</dfn>
-</p><h2><span class="secno">1.1. </span>Heading 2</h2><p><dfn id="ltm-termgt"><em>&lt;M-term&gt;</em></dfn>
-</p><h3><span class="secno">1.1.1. </span>Heading 3</h3><p><dfn id="z-term">Z-term</dfn>
-</p><h1><span class="secno">2. </span>Index</h1><ul class="indexlist">
+<html><body><h1><span class="secno">1. </span>Heading 0</h1>
+<h1 class="no-num">Heading 1</h1>
+<p><dfn id="a-term">A-term</dfn>
+</p><h2><span class="secno">1.1. </span>Heading 2</h2>
+<p><dfn id="ltm-termgt"><em>&lt;M-term&gt;</em></dfn>
+</p><h3><span class="secno">1.1.1. </span>Heading 3</h3>
+<p><dfn id="z-term">Z-term</dfn>
+</p><h1><span class="secno">2. </span>Index</h1>
+<ul class="indexlist">
 <li>term
   <ul>
   <li>A, <a href="#a-term" title="section ??"><strong>??</strong></a>
@@ -36,4 +41,4 @@ cat >$TMP3 <<EOF
 </ul></body></html>
 EOF
 
-cmp -s $TMP2 $TMP3
+diff -u $TMP3 $TMP2
