@@ -27,14 +27,19 @@ EOF
 (./hxnum $TMP1 | LC_ALL=C ./hxindex -t -n -f; echo) >$TMP2
 
 cat >$TMP3 <<EOF
-<html><body><h1><span class="secno">1. </span>Heading 0</h1><h1 class="no-num">Heading 1</h1><p><dfn id="a-term">A-term</dfn>
+<html><body><h1><span class="secno">1. </span>Heading 0</h1>
+<h1 class="no-num">Heading 1</h1>
+<p><dfn id="a-term">A-term</dfn>
 </p><p><span id="z-term" class="index">Z-term</span>
-</p><h2><span class="secno">1.1. </span>Heading 2</h2><p><dfn id="ltm-termgt"><em>&lt;M-term&gt;</em></dfn>
+</p><h2><span class="secno">1.1. </span>Heading 2</h2>
+<p><dfn id="ltm-termgt"><em>&lt;M-term&gt;</em></dfn>
 </p><p><span id="a-term0" class="index">A-term</span>
-</p><h3><span class="secno">1.1.1. </span>Heading 3</h3><p><dfn id="z-term0">Z-term</dfn>
+</p><h3><span class="secno">1.1.1. </span>Heading 3</h3>
+<p><dfn id="z-term0">Z-term</dfn>
 </p><p><span id="m-term" class="index">M-term</span>
 </p><p><span id="termm." class="index">term!!M.</span>
-</p><h1><span class="secno">2. </span>Index</h1><ul class="indexlist">
+</p><h1><span class="secno">2. </span>Index</h1>
+<ul class="indexlist">
 <li>term
   <ul>
   <li>A, <a href="#a-term" title="section ??"><strong>??</strong></a>, <a href="#a-term0" title="section 1.1.">1.1.</a>
@@ -44,4 +49,4 @@ cat >$TMP3 <<EOF
 </ul></body></html>
 EOF
 
-cmp -s $TMP2 $TMP3
+diff -u $TMP3 $TMP2
