@@ -26,10 +26,15 @@ EOF
 
 cat >$TMP3 <<EOF
 <html><head><title>Document title</title></head><body><p><dfn id="term">0-term</dfn>
-</p><h1><span class="secno">1. </span>Heading 0</h1><h1 class="no-num">Heading 1</h1><p><dfn id="a-term">A-term</dfn>
-</p><h2><span class="secno">1.1. </span>Heading 2</h2><p><dfn id="ltm-termgt"><em>&lt;M-term&gt;</em></dfn>
-</p><h3><span class="secno">1.1.1. </span>Heading 3</h3><p><dfn id="z-term">Z-term</dfn>
-</p><h1><span class="secno">2. </span>Index</h1><!--begin-index-->
+</p><h1><span class="secno">1. </span>Heading 0</h1>
+<h1 class="no-num">Heading 1</h1>
+<p><dfn id="a-term">A-term</dfn>
+</p><h2><span class="secno">1.1. </span>Heading 2</h2>
+<p><dfn id="ltm-termgt"><em>&lt;M-term&gt;</em></dfn>
+</p><h3><span class="secno">1.1.1. </span>Heading 3</h3>
+<p><dfn id="z-term">Z-term</dfn>
+</p><h1><span class="secno">2. </span>Index</h1>
+<!--begin-index-->
 <ul class="indexlist">
 <li>0-term, <a href="#term"><strong>Document title</strong></a>
 <li>&lt;M-term&gt;, <a href="#ltm-termgt"><strong><span class="secno">1.1. </span>Heading 2</strong></a>
@@ -38,4 +43,4 @@ cat >$TMP3 <<EOF
 </ul><!--end-index--></body></html>
 EOF
 
-diff -u $TMP2 $TMP3
+diff -u $TMP3 $TMP2
