@@ -29,4 +29,4 @@ cat >$TMP2 <<-EOF
 	</dl>
 EOF
 ./hxnormalize -i 0 -L $TMP1 >$TMP3
-cmp -s $TMP2 $TMP3
+diff -u $TMP2 $TMP3
