@@ -24,7 +24,7 @@ cat >$TMP2 <<-EOF
 	<!DOCTYPE html>
 
 	<html>
-	  <body>
+	  <head>
 	    <script>//<![CDATA[
 	Not a delimiter: <
 	Not a delimiter: </
@@ -38,4 +38,4 @@ cat >$TMP2 <<-EOF
 	    <p><![CDATA[<p></p>]]>
 EOF
 ./hxnormalize -i 2 $TMP1 >$TMP3
-cmp -s $TMP2 $TMP3
+diff -u $TMP2 $TMP3
