@@ -17,10 +17,10 @@ cat >$TMP2 <<-EOF
 
 	<html lang="en">
 	<head>
-	<style><![CDATA[
-	/* no <elements> or <![CDATA[ mark-up here */
-	]]></style></head>
+	<style>
+	/* no &lt;elements> or &lt;![CDATA[ mark-up here */
+	</style></head>
 	</html>
 EOF
-./hxnormalize -i 0 -x $TMP1 | ./hxnormalize -i 0 -x >$TMP3
-cmp -s $TMP2 $TMP3
+./hxnormalize -i 0 -x $TMP1 | ./hxnormalize -i 0 -X -x >$TMP3
+diff -u $TMP2 $TMP3
