@@ -28,5 +28,5 @@ cat >$TMP2 <<-EOF
 	<body>
 	<p>...
 EOF
-./hxnormalize -x $TMP1 | ./hxnormalize -i 0 >$TMP3
-cmp -s $TMP2 $TMP3
+./hxnormalize -x $TMP1 | ./hxnormalize -i 0 -X >$TMP3
+diff -u $TMP2 $TMP3
