@@ -4,7 +4,7 @@ TMP1=`mktemp /tmp/tmp.XXXXXXXXXX` || exit 1
 TMP2=`mktemp /tmp/tmp.XXXXXXXXXX` || exit 1
 
 ./hxpipe >$TMP1 <<-EOF
-	<abc foo1=bar1 foo2="bar2 bar2">
+	<abc xxx="bar2 bar2" aaa=bar1>
 	text1
 	<def/>
 	<_foo>text2</_foo>
@@ -12,8 +12,8 @@ TMP2=`mktemp /tmp/tmp.XXXXXXXXXX` || exit 1
 	</abc>
 EOF
 cat >$TMP2 <<-EOF
-Afoo1 CDATA bar1
-Afoo2 CDATA bar2 bar2
+Aaaa CDATA bar1
+Axxx CDATA bar2 bar2
 (abc
 -\ntext1\n
 |def
