@@ -15,10 +15,10 @@ cat >$TMP1 <<-EOF
 (./hxref $TMP1; echo) >$TMP2
 
 cat >$TMP3 <<-EOF
-	<html><body><p><a href="#term">other</a>
+	<html><body><a href="#term">other</a>
 	text...
 	<dfn id="term" title="other">term</dfn>
-	</p></body></html>
+	</body></html>
 	EOF
 
-cmp -s $TMP2 $TMP3
+diff -u $TMP3 $TMP2
