@@ -6,6 +6,8 @@ TMP2=`mktemp /tmp/addidXXXXXXXX` || exit 1
 
 ./hxselect -s '\n' 'div + ul > li:nth-child(-n+2)' >$TMP1 <<-EOF
 	<div><p>Not this.</p></div>
+	Some text
+	<!-- A comment -->
 	<ul>
 	<li>This</li>
 	<li>And this</li>
