@@ -7,6 +7,8 @@ TMP2=`mktemp /tmp/select18-XXXXXX` || exit 1
 ./hxselect -s '\n' 'div div' >$TMP1 <<-EOF
 	<div id=d1>
 	 <div id=d2 />
+	 Some text
+	 <!-- A comment -->
 	 <div id=d3 />
 	 <div id=d4 />
 	</div>
