@@ -17,7 +17,8 @@ EOF
 echo >>$TMP1			# Add newline
 
 cat >$TMP2 <<-EOF
-<html><head><title>Test</title></head><body><h1 id="document-heading">Document heading</h1><!--begin-toc-->
+<html><head><title>Test</title></head><body><h1 id="document-heading">Document heading</h1>
+<!--begin-toc-->
 <ul class="toc">
 <li><a href="#document-heading">Document heading</a>
  <ul class="toc">
@@ -26,12 +27,14 @@ cat >$TMP2 <<-EOF
   <li><a href="#third-level-heading-">Third-level heading</a>
   </ul>
  </ul></ul>
-<!--end-toc--><section id="second-level-heading-third-level-heading">
+<!--end-toc-->
+<section id="second-level-heading-third-level-heading">
 <h1>Second-level heading</h1>
 <section id="third-level-heading-">
 <h6>Third-level heading</h6>
 </section>
-</section></body></html>
+</section>
+</body></html>
 EOF
 
-cmp -s $TMP1 $TMP2
+diff -u $TMP2 $TMP1
