@@ -13,7 +13,8 @@ EOF
 echo >>$TMP1			# Add newline
 
 cat >$TMP2 <<-EOF
-<html><head><title>Test</title></head><body><h1 id="document-heading">Document heading</h1><!--begin-toc-->
+<html><head><title>Test</title></head><body><h1 id="document-heading">Document heading</h1>
+<!--begin-toc-->
 <ul class="toc">
 <li><a href="#document-heading">Document heading</a>
  <ul class="toc">
@@ -22,7 +23,10 @@ cat >$TMP2 <<-EOF
   <li><a href="#third-level-heading">Third-level heading</a>
   </ul>
  </ul></ul>
-<!--end-toc--><h2 id="second-level-heading">Second-level heading</h2><h3 id="third-level-heading">Third-level heading</h3></body></html>
+<!--end-toc-->
+<h2 id="second-level-heading">Second-level heading</h2>
+<h3 id="third-level-heading">Third-level heading</h3>
+</body></html>
 EOF
 
-cmp -s $TMP1 $TMP2
+diff -u $TMP2 $TMP1
