@@ -14,7 +14,8 @@ EOF
 echo >>$TMP1			# Add newline
 
 cat >$TMP2 <<-EOF
-<html><head><title>Test</title></head><body><h1 id="document-heading">Document <b>heading</b></h1><!--begin-toc-->
+<html><head><title>Test</title></head><body><h1 id="document-heading">Document <b>heading</b></h1>
+<!--begin-toc-->
 <ul class="toc">
 <li><a href="#document-heading">Document heading</a>
  <ul class="toc">
@@ -24,7 +25,11 @@ cat >$TMP2 <<-EOF
   <li><a href="#another-third-level-heading">Another <span dir="ltr">Third-level</span> heading</a>
   </ul>
  </ul></ul>
-<!--end-toc--><h2 id="second-level-">Second-level <img src="" alt="heading"></h2><h3 id="third-level-heading">Third-level <bdo dir="ltr">heading</bdo></h3><h3 id="another-third-level-heading">Another <abbr title="none" dir="ltr">Third-level</abbr> heading</h3></body></html>
+<!--end-toc-->
+<h2 id="second-level-">Second-level <img src="" alt="heading"></h2>
+<h3 id="third-level-heading">Third-level <bdo dir="ltr">heading</bdo></h3>
+<h3 id="another-third-level-heading">Another <abbr title="none" dir="ltr">Third-level</abbr> heading</h3>
+</body></html>
 EOF
 
-cmp -s $TMP1 $TMP2
+diff -u $TMP2 $TMP1
