@@ -23,10 +23,12 @@ cat >$TMP1 <<EOF
 EOF
 
 cat >$TMP2 <<EOF
-<!DOCTYPE html><html><head lang="en"><meta charset="UTF-8"><title>Title</title></head><body><p>
+<!DOCTYPE html><html><head lang="en"><meta charset="UTF-8"><title>Title</title></head><body>
+<p>
 <video controls><source src="gillette_media/powwow_highway.mp4" type="video/mp4">Video</video>
 <em>Powwow Highway: Gillette scene</em>
-</p></body></html>
+</p>
+</body></html>
 EOF
 
 ./hxtoc $TMP1 >$TMP3
